@@ -15,74 +15,122 @@ def _to_seconds(timestamp: int) -> int:
 class RiotApiResponse:
     """
     Superclass of all API responses.
-    
+
     :param success: wether the response was successful. Useful to spot errors
     :type success: bool
     """
-    
+
     def __init__(self, success: bool = True, **kwargs):
         self.__success = success
         for key, value in kwargs.items():
             setattr(self, key, value)
-    
-    def to_string(self, *, level: int = 0, sep = '    ', nl: str = '\n'):
+
+    def to_string(
+            self, *,
+            level: int = 0,
+            indent_char = '    ',
+            nl: str = '\n',
+            o_par: str = '(',
+            c_par: str = ')',
+            sep: str = '=',
+            show_class_name: bool = True,
+            quote_attrs: bool = False,
+            skip_none: bool = False,
+            lower_bools: bool = False
+    ) -> str:
         """
         Returns a prettified string representation of the object.
-        
+
         :param level: starting level of indentation. Default: 0
-        :param sep: character sequence for indentation. Default: 4 spaces
+        :param indent_char: character sequence for indentation. Default: 4 spaces
         :param nl: new line sequence. Default '\\n'
+        :param o_par: parenthesis to use when opening the object. Default: '('
+        :param c_par: parenthesis to use when closing the object. Default: ')'
+        :param show_class_name: whether to show the class name at the beginning of each complex object. Default: True
+        :param sep: separator to use when printing the name value of an object. Default: '='
+        :param quote_attrs: whether to quote the attribute name. Default: False
         :type level: int
-        :type sep: str
+        :type indent_char: str
         :type nl: str
+        :type o_par: str
+        :type c_par: str
+        :type show_class_name: bool
+        :type sep: str
+        :type quote_attrs: bool
         """
-        
-        def recursion(obj, level: int = level, sep = sep):
+
+        def recursion(obj, level: int = level, indent_char = indent_char):
             if isinstance(obj, RiotApiResponse):
-                return obj.to_string(level = level + 1, sep = sep)
+                return obj.to_string(
+                    level = level + 1,
+                    indent_char = indent_char,
+                    nl = nl,
+                    o_par = o_par,
+                    c_par = c_par,
+                    sep = sep,
+                    show_class_name = show_class_name,
+                    quote_attrs = quote_attrs,
+                    skip_none = skip_none,
+                    lower_bools = lower_bools
+                )
             if isinstance(obj, list):
-                return f'[{nl}{sep * (level + 2)}' + (
-                    f',{nl}{sep * (level + 2)}'.join(
-                        map(lambda x: recursion(x, level + 1, sep), obj)
-                    )) + f'\n{sep * (level + 1)}]'
+                return f'[{nl}{indent_char * (level + 2)}' + (
+                    f',{nl}{indent_char * (level + 2)}'.join(
+                        map(lambda x: recursion(x, level + 1, indent_char), obj)
+                    )) + f'\n{indent_char * (level + 1)}]'
+            if isinstance(obj, str):
+                return f'"{obj}"'
+            if isinstance(obj, bool):
+                return str(obj).lower() if lower_bools else str(obj)
             return str(obj)
-        
+
         to_skip = ['success', 'error', '_RiotApiResponse__success']
-        return '{}({}{}{}{}{})'.format(
-            type(self).__name__,
+        return '{}{}{}{}{}{}{}{}'.format(
+            type(self).__name__ if show_class_name else '',
+            o_par,
             nl,
-            sep * (level + 1),
-            f',{nl}{sep * (level + 1)}'.join(
-                '{} = {}'.format(*item) for item in map(
+            indent_char * (level + 1),
+            f',{nl}{indent_char * (level + 1)}'.join(
+                '{}{}{} {} {}'.format('"' if quote_attrs else '', item[0], '"' if quote_attrs else '', sep, item[1])
+                for item in map(
                     lambda x: (x[0], recursion(x[1])),
-                    filter(lambda x: x[0] not in to_skip, vars(self).items())
+                    filter(lambda x: x[0] not in to_skip and (not skip_none or x[1] is not None), vars(self).items())
                 )
             ),
             nl,
-            sep * level,
+            indent_char * level,
+            c_par
         )
-    
+
     def __repr__(self):
         return self.to_string()
-    
+
     def __bool__(self):
         return self.__success
-    
-    def toJSON(self, indent: Optional[int] = None, separators: Optional[Tuple[str, str]] = None):
-        return json.dumps(self, default = lambda o: o.__dict__, indent = indent, separators = separators)
+
+    def toJSON(self):
+        return self.to_string(
+            o_par = '{',
+            c_par = '}',
+            sep = ':',
+            show_class_name = False,
+            quote_attrs = True,
+            skip_none = True,
+            lower_bools = True
+        )
 
 
 # ERROR
 class RiotApiError(RiotApiResponse):
     """
     General API response error.
-    
+
     :param message: message contained in the response. Default 'Bad Request'
     :param status_code: error code from the response. Default 400
     :type message: str
     :type status_code: int
     """
-    
+
     def __init__(self, message: str = 'Bad Request', status_code: int = 400, **kwargs):
         super().__init__(False, **kwargs)
         self.message = message
@@ -92,7 +140,7 @@ class RiotApiError(RiotApiResponse):
 class ShortChampionDD(RiotApiResponse):
     """
     Short information about a champion
-    
+
     :param blurb: short description
     :param id: name of the champion without non-alphabetic characters
     :param image: information about the images of a champion
@@ -115,13 +163,13 @@ class ShortChampionDD(RiotApiResponse):
     :type tags: List[str]
     :type title: str
     :type version: str
-    
+
     Other attributes:
         int_id (``int``):
             integer representation of param ``ShortChampionDD.key``. Not present in the original data type,
             useful for some methods and, more importantly, coherent with the represented value
     """
-    
+
     def __init__(self, blurb: str, id: str, image: dict, info: dict, key: str, name: str, partype: str, stats: dict,
                  tags: List[str], title: str, version: str, **kwargs):
         super().__init__(**kwargs)
@@ -142,9 +190,9 @@ class ShortChampionDD(RiotApiResponse):
 class ChampionDD(ShortChampionDD):
     """
     Complete information about a champion.
-    
+
     Look at :class:`ShortChampionDD` for the complete list of parameters.
-    
+
     :param skins: list of skins
     :param lore: lore of the champion
     :param allytips: list of tips for summoners playing the champion
@@ -160,7 +208,7 @@ class ChampionDD(ShortChampionDD):
     :type passive: :class:`ChampionPassiveDD`
     :type recommended: List[unknown]
     """
-    
+
     def __init__(self, id: str, key: str, name: str, title: str, image: dict, skins: List[dict], lore: str, blurb: str,
                  allytips: List[str], enemytips: List[str], tags: List[str], partype: str, info: dict, stats: dict,
                  spells: List[dict], passive: dict, recommended: list, version: str, **kwargs):
@@ -190,7 +238,7 @@ class ChampionDD(ShortChampionDD):
 class ChampionImageDD(RiotApiResponse):
     """
     Details about the champion's image.
-    
+
     :param full: file name of the image. The complete url can be obtained from
         :meth:`~async_riot_api.LoLAPI.get_champion_image_url_from_id`
     :param sprite: don't really know what this is, some kind of image with more images inside.
@@ -208,7 +256,7 @@ class ChampionImageDD(RiotApiResponse):
     :type w: int
     :type h: int
     """
-    
+
     def __init__(self, full: str, sprite: str, group: str, x: int, y: int, w: int, h: int, **kwargs):
         super().__init__(**kwargs)
         self.full = full
@@ -223,7 +271,7 @@ class ChampionImageDD(RiotApiResponse):
 class ChampionSkinDD(RiotApiResponse):
     """
     Details about the champion's skins.
-    
+
     :param id: unique id of the skin. It is made by concatenating the champ ID and the skin number (with 3 digits).
         Example: champion "Veigar" (ID 45), skin "Final Boss" (num 8), result: "45008"
     :param num: number of the skin
@@ -234,7 +282,7 @@ class ChampionSkinDD(RiotApiResponse):
     :type name: str
     :type chromas: bool
     """
-    
+
     def __init__(self, id: str, num: int, name: str, chromas: bool, **kwargs):
         super().__init__(**kwargs)
         self.id = id
@@ -246,7 +294,7 @@ class ChampionSkinDD(RiotApiResponse):
 class ChampionInfoDD(RiotApiResponse):
     """
     Schematic information about the champion. You can find this information in the LoL client by going to a champion's page.
-    
+
     :param attack: the higher this value, the higher the champion deals damage using auto attacks
     :param defense: the higher this value, the higher the champion is tanky
     :param magic: the higher this value, the higher the champion deals damage using spells
@@ -256,7 +304,7 @@ class ChampionInfoDD(RiotApiResponse):
     :type magic: int
     :type difficulty: int
     """
-    
+
     def __init__(self, attack: int, defense: int, magic: int, difficulty: int, **kwargs):
         super().__init__(**kwargs)
         self.attack = attack
@@ -272,7 +320,7 @@ class ChampionStatsDD(RiotApiResponse):
         - ``u`` stands for "unit"
         - ``l`` stands for "level"
         - ``s`` stands for "second"
-    
+
     :param hp: base health points (``u``)
     :param hpperlevel: extra HP per level (``u / l``)
     :param mp: base mana points (``u``)
@@ -314,7 +362,7 @@ class ChampionStatsDD(RiotApiResponse):
     :type attackspeedperlevel: float
     :type attackspeed: float
     """
-    
+
     def __init__(self, hp: int, hpperlevel: int, mp: int, mpperlevel: int, movespeed: int, armor: int,
                  armorperlevel: float, spellblock: int, spellblockperlevel: float, attackrange: int, hpregen: int,
                  hpregenperlevel: int, mpregen: int, mpregenperlevel: int, crit: int, critperlevel: int,
@@ -347,7 +395,7 @@ class ChampionSpellDD(RiotApiResponse):
     """
     Specific information about a champion spell (skill). Complete documentation about string placeholders and parsing is
     `here <https://developer.riotgames.com/docs/lol>`_.
-    
+
     :param id: spell's ID, including champion name and spell name
     :param name: spell's name
     :param description: spell's description
@@ -390,7 +438,7 @@ class ChampionSpellDD(RiotApiResponse):
     :type image: :class:`ChampionSpellImageDD`
     :type resource: Optional[str]
     """
-    
+
     def __init__(self, id: str, name: str, description: str, tooltip: str, maxrank: int,
                  cooldown: List[int], cooldownBurn: str, cost: List[int], costBurn: str, datavalues: dict,
                  effect: List[Optional[List[int]]], effectBurn: List[Optional[str]], vars: List[Any], costType: str,
@@ -467,7 +515,7 @@ class ChampionPassiveImageDD(RiotApiResponse):
 class QueueDD(RiotApiResponse):
     """
     Representation of a queue. Not actually returned by any API call, but still usefu sometimes.
-    
+
     :param queueId: queue ID
     :param map: map name
     :param description: description of the queue
@@ -477,7 +525,7 @@ class QueueDD(RiotApiResponse):
     :type description: str
     :type notes: str
     """
-    
+
     def __init__(self, queueId: int, map: str, description: str, notes: str, **kwargs):
         super().__init__(**kwargs)
         self.queueId = queueId
@@ -490,7 +538,7 @@ class QueueDD(RiotApiResponse):
 class AccountDto(RiotApiResponse):
     """
     Basic information about a Riot Games account.
-    
+
     :param puuid: puuid of the account. Useful for many API methods
     :param gameName: in-game name of the account
     :param tagLine: tag line of the account
@@ -498,7 +546,7 @@ class AccountDto(RiotApiResponse):
     :type gameName: str
     :type tagLine: str
     """
-    
+
     def __init__(self, puuid: str, gameName: str, tagLine: str, **kwargs):
         super().__init__(**kwargs)
         self.puuid = puuid
@@ -509,7 +557,7 @@ class AccountDto(RiotApiResponse):
 class ActiveShardDto(RiotApiResponse):
     """
     No idea about what this is. Probably the server in which the summoner plays.
-    
+
     :param puuid: puuid
     :param game: game. Can be 'val' or 'lor'
     :param activeShard: probably the server in which the summoner plays
@@ -517,7 +565,7 @@ class ActiveShardDto(RiotApiResponse):
     :type game: str
     :type activeShard: str
     """
-    
+
     def __init__(self, puuid: str, game: str, activeShard: str, **kwargs):
         super().__init__(**kwargs)
         self.puuid = puuid
@@ -529,7 +577,7 @@ class ActiveShardDto(RiotApiResponse):
 class ChampionMasteryDto(RiotApiResponse):
     """
     Information about a summoner's mastery levels, tokens and chests.
-    
+
     :param championPointsUntilNextLevel: points needed for the mastery to upgrade to the next level
     :param chestGranted: if the player already got the weekly chest on the champion
     :param championId: champion ID
@@ -551,7 +599,7 @@ class ChampionMasteryDto(RiotApiResponse):
     :type championPointsSinceLastLevel: int
     :type tokensEarned: int
     """
-    
+
     def __init__(self, championPointsUntilNextLevel: int, chestGranted: bool, championId: int, lastPlayTime: int,
                  championLevel: int, summonerId: str, championPoints: int, championPointsSinceLastLevel: int,
                  tokensEarned: int, **kwargs):
@@ -572,7 +620,7 @@ class ChampionMasteryDto(RiotApiResponse):
 class ChampionInfo(RiotApiResponse):
     """
     Information about the current champion rotation and the new players' champion rotation.
-    
+
     :param maxNewPlayerLevel: max level for a player to have the beginner rotation available
     :param freeChampionIdsForNewPlayers: list of champion IDs free-to-play for beginners
     :param freeChampionIds: list of champion IDs free-to-play for non-beginner players
@@ -580,7 +628,7 @@ class ChampionInfo(RiotApiResponse):
     :type freeChampionIdsForNewPlayers: List[int]
     :type freeChampionIds: List[int[
     """
-    
+
     def __init__(self, maxNewPlayerLevel: int, freeChampionIdsForNewPlayers: List[int], freeChampionIds: List[int],
                  **kwargs):
         super().__init__(**kwargs)
@@ -593,7 +641,7 @@ class ChampionInfo(RiotApiResponse):
 class PlayerDto(RiotApiResponse):
     """
     Data about a player in a clash.
-    
+
     :param summonerId: summoner ID
     :param teamId: team ID
     :param position: position selected by the summoner
@@ -603,7 +651,7 @@ class PlayerDto(RiotApiResponse):
     :type position: str
     :type role: str
     """
-    
+
     def __init__(self, summonerId: str, teamId: str, position: str, role: str, **kwargs):
         super().__init__(**kwargs)
         self.summonerId = summonerId
@@ -612,10 +660,24 @@ class PlayerDto(RiotApiResponse):
         self.role = role
 
 
+class ClashTeamDto(RiotApiResponse):
+    def __init__(self, id: str, tournamentId: int, name: str, iconId: int, tier: int, captain: str, abbreviation: str,
+                 players: List[dict], **kwargs):
+        super().__init__()
+        self.id = id
+        self.tournamentId = tournamentId
+        self.name = name
+        self.iconId = iconId
+        self.tier = tier
+        self.captain = captain
+        self.abbreviation = abbreviation
+        self.players: List[PlayerDto] = list(map(lambda x: PlayerDto(**x), players))
+
+
 class TournamentDto(RiotApiResponse):
     """
     Information about a tournament.
-    
+
     :param id: tournament ID
     :param themeId: no idea, not originally documented
     :param nameKey: no idea, not originally documented
@@ -627,7 +689,7 @@ class TournamentDto(RiotApiResponse):
     :type nameKeySecondary: str
     :type schedule: :class:`TournamentPhaseDto`
     """
-    
+
     def __init__(self, id: int, themeId: int, nameKey: str, nameKeySecondary: str, schedule: List[dict], **kwargs):
         super().__init__(**kwargs)
         self.id = id
@@ -640,7 +702,7 @@ class TournamentDto(RiotApiResponse):
 class TournamentPhaseDto(RiotApiResponse):
     """
     Schedule information for a tournament.
-    
+
     :param id: ID
     :param registrationTime: timestamp in ms
     :param registrationTimeSeconds: timestamp in seconds
@@ -654,7 +716,7 @@ class TournamentPhaseDto(RiotApiResponse):
     :type startTimeSeconds: int
     :type cancelled: bool
     """
-    
+
     def __init__(self, id: int, registrationTime: int, startTime: int, cancelled: bool, **kwargs):
         super().__init__(**kwargs)
         self.id = id
@@ -669,7 +731,7 @@ class TournamentPhaseDto(RiotApiResponse):
 class LeagueListDTO(RiotApiResponse):
     """
     List of information about leagues for summoners in the same queue.
-    
+
     :param tier: rank tier, like 'CHALLENGER' or 'MASTER'
     :param leagueId: league ID
     :param queue: queue type, like 'RANKED_SOLO_5x5'
@@ -681,7 +743,7 @@ class LeagueListDTO(RiotApiResponse):
     :type name: str
     :type entries: List[:class:`LeagueItemDTO`]
     """
-    
+
     def __init__(self, tier: str, leagueId: str, queue: str, name: str, entries: List[dict], **kwargs):
         super().__init__(**kwargs)
         self.tier = tier
@@ -695,7 +757,7 @@ class LeagueItemDTO(RiotApiResponse):
     """
     Simplified information about a summoner's rank in a queue, returned by methods for apex tiers.
     Some information are missing since they are included in the higher level object ``LeagueListDTO`` containing this object.
-    
+
     :param summonerId: summoner ID
     :param summonerName: summoner name
     :param leaguePoints: aka LP
@@ -719,7 +781,7 @@ class LeagueItemDTO(RiotApiResponse):
     :type hotStreak: bool
     :type miniSeries: Optional[:class:`MiniSeriesDTO`]
     """
-    
+
     def __init__(self, summonerId: str, summonerName: str, leaguePoints: int, rank: str, wins: int, losses: int,
                  veteran: bool, inactive: bool, freshBlood: bool, hotStreak: bool, miniSeries: Optional[dict] = None,
                  **kwargs):
@@ -742,20 +804,20 @@ class LeagueEntryDTO(LeagueItemDTO):
     Complete information about summoner's league.
 
     Look at :class:`LeagueItemDTO` for the complete list of parameters.
-    
+
     :param queueType: queue for this entry, like 'RANKED_SOLO_5x5'
     :param leagueId: league ID
     :param tier: tier for this entry, like 'SILVER' or 'DIAMOND'
     :type queueType: str
     :type leagueId: Optional[str]
     :type tier: Optional[str]
-    
+
     Other attributes:
         short (``Optional[str]``):
             short representation of rank and tier. For example 'DIAMOND III' becomes 'D3'.
             Exception is made for 'GRANDMASTER x' which becomes 'GMx' due to the ambuguity between 'GOLD' and 'GRANDMASTER'
     """
-    
+
     def __init__(self, summonerId: str, summonerName: str, queueType: str, leaguePoints: int, wins: int, losses: int,
                  hotStreak: bool, veteran: bool, freshBlood: bool, inactive: bool, miniSeries: Optional[dict] = None,
                  leagueId: Optional[str] = None, tier: Optional[str] = None, rank: Optional[str] = None, **kwargs):
@@ -777,7 +839,7 @@ class LeagueEntryDTO(LeagueItemDTO):
         self.queueType = queueType
         self.tier = tier
         self.short: Optional[str] = LeagueEntryDTO.__get_short(self.tier, self.rank)
-    
+
     @staticmethod
     def __get_short(tier: str, rank: str) -> Optional[str]:
         if not (tier and rank):
@@ -791,7 +853,7 @@ class MiniSeriesDTO(RiotApiResponse):
     Miniseries consist in 5 matches in which you have to win 3 times to get promoted.
     Before season 11, miniseries were also required when passing from a rank to another,
     with 3 matches instead of 5 and 2 victories instead of 3.
-    
+
     :param losses: losses in this miniseries
     :param progress: string representing wins and losses. for example 'WWLNN' means two wins, one loss and two matches remained
     :param target: number of wins to reach
@@ -801,7 +863,7 @@ class MiniSeriesDTO(RiotApiResponse):
     :type target: int
     :type wins: int
     """
-    
+
     def __init__(self, losses: int, progress: str, target: int, wins: int, **kwargs):
         super().__init__(**kwargs)
         self.losses = losses
@@ -915,13 +977,13 @@ class UpdateDto(RiotApiResponse):
 class LorMatchDto(RiotApiResponse):
     """
     Base object containing inforamtion about a LoR match.
-    
+
     :param metadata: to access the ordered list of participants
     :param info: more detailed infor about players
     :type metadata: :class:`LorMetadataDto`
     :type info: :class:`LorInfoDto`
     """
-    
+
     def __init__(self, metadata: dict, info: dict, **kwargs):
         super().__init__(**kwargs)
         self.metadata: LorMetadataDto = LorMetadataDto(**metadata)
@@ -931,7 +993,7 @@ class LorMatchDto(RiotApiResponse):
 class LorMetadataDto(RiotApiResponse):
     """
     Metadata about the match.
-    
+
     :param data_version: version of the game
     :param match_id: match ID
     :param participants: ordered list of participants, represented by their puuid
@@ -939,7 +1001,7 @@ class LorMetadataDto(RiotApiResponse):
     :type match_id: str
     :type participants: List[str]
     """
-    
+
     def __init__(self, data_version: str, match_id: str, participants: List[str], **kwargs):
         super().__init__(**kwargs)
         self.data_version = data_version
@@ -950,7 +1012,7 @@ class LorMetadataDto(RiotApiResponse):
 class LorInfoDto(RiotApiResponse):
     """
     Detailed information about a LoR match. Contains information about mode, duration and players.
-    
+
     :param game_mode: game mode
     :param game_type: game type
     :param game_start_time_utc: game start time utc
@@ -964,7 +1026,7 @@ class LorInfoDto(RiotApiResponse):
     :type players: List[:class:`LorPlayerDto`]
     :type total_turn_count: int
     """
-    
+
     def __init__(self, game_mode: str, game_type: str, game_start_time_utc: str, game_version: str, players: List[dict],
                  total_turn_count: int, **kwargs):
         super().__init__(**kwargs)
@@ -979,7 +1041,7 @@ class LorInfoDto(RiotApiResponse):
 class LorPlayerDto(RiotApiResponse):
     """
     Detailed information about a player in a LoR match.
-    
+
     :param puuid: puuid
     :param deck_id: deck ID
     :param deck_code: deck code
@@ -993,7 +1055,7 @@ class LorPlayerDto(RiotApiResponse):
     :type game_outcome: str
     :type order_of_play: int
     """
-    
+
     def __init__(self, puuid: str, deck_id: str, deck_code: str, factions: List[str], game_outcome: str,
                  order_of_play: int, **kwargs):
         super().__init__(**kwargs)
@@ -1012,7 +1074,7 @@ class LorLeaderboardDto(RiotApiResponse):
     :param players: list of players
     :type players: List[:class:`LorLeaderboardPlayerDto`]
     """
-    
+
     def __init__(self, players: List[dict], **kwargs):
         super().__init__(**kwargs)
         self.players: List[LorLeaderboardPlayerDto] = list(map(lambda x: LorLeaderboardPlayerDto(**x), players))
@@ -1021,7 +1083,7 @@ class LorLeaderboardDto(RiotApiResponse):
 class LorLeaderboardPlayerDto(RiotApiResponse):
     """
     Information about a player in LoR Master tier.
-    
+
     :param name: summoner's name
     :param rank: summoner's rank
     :param lp: summoner's LP
@@ -1029,7 +1091,7 @@ class LorLeaderboardPlayerDto(RiotApiResponse):
     :type rank: int
     :type lp: int
     """
-    
+
     def __init__(self, name: str, rank: int, lp: int, **kwargs):
         super().__init__(**kwargs)
         self.name = name
@@ -1104,217 +1166,217 @@ class ParticipantDto(RiotApiResponse):
                  visionWardsBoughtInGame: int, wardsKilled: int, wardsPlaced: int, win: bool,
                  inhibitorTakedowns: int = 0, nexusTakedowns: int = 0, turretTakedowns: int = 0, **kwargs):
         """
-        
-        :param assists: 
-        :param baronKills: 
-        :param bountyLevel: 
-        :param champExperience: 
-        :param champLevel: 
-        :param championId: 
-        :param championName: 
-        :param championTransform: 
-        :param consumablesPurchased: 
-        :param damageDealtToBuildings: 
-        :param damageDealtToObjectives: 
-        :param damageDealtToTurrets: 
-        :param damageSelfMitigated: 
-        :param deaths: 
-        :param detectorWardsPlaced: 
-        :param doubleKills: 
-        :param dragonKills: 
-        :param firstBloodAssist: 
-        :param firstBloodKill: 
-        :param firstTowerAssist: 
-        :param firstTowerKill: 
-        :param gameEndedInEarlySurrender: 
-        :param gameEndedInSurrender: 
-        :param goldEarned: 
-        :param goldSpent: 
-        :param individualPosition: 
-        :param inhibitorKills: 
-        :param inhibitorsLost: 
-        :param item0: 
-        :param item1: 
-        :param item2: 
-        :param item3: 
-        :param item4: 
-        :param item5: 
-        :param item6: 
-        :param itemsPurchased: 
-        :param killingSprees: 
-        :param kills: 
-        :param lane: 
-        :param largestCriticalStrike: 
-        :param largestKillingSpree: 
-        :param largestMultiKill: 
-        :param longestTimeSpentLiving: 
-        :param magicDamageDealt: 
-        :param magicDamageDealtToChampions: 
-        :param magicDamageTaken: 
-        :param neutralMinionsKilled: 
-        :param nexusKills: 
-        :param nexusLost: 
-        :param objectivesStolen: 
-        :param objectivesStolenAssists: 
-        :param participantId: 
-        :param pentaKills: 
-        :param perks: 
-        :param physicalDamageDealt: 
-        :param physicalDamageDealtToChampions: 
-        :param physicalDamageTaken: 
-        :param profileIcon: 
-        :param puuid: 
-        :param quadraKills: 
-        :param riotIdName: 
-        :param riotIdTagline: 
-        :param role: 
-        :param sightWardsBoughtInGame: 
-        :param spell1Casts: 
-        :param spell2Casts: 
-        :param spell3Casts: 
-        :param spell4Casts: 
-        :param summoner1Casts: 
-        :param summoner1Id: 
-        :param summoner2Casts: 
-        :param summoner2Id: 
-        :param summonerId: 
-        :param summonerLevel: 
-        :param summonerName: 
-        :param teamEarlySurrendered: 
-        :param teamId: 
-        :param teamPosition: 
-        :param timeCCingOthers: 
-        :param timePlayed: 
-        :param totalDamageDealt: 
-        :param totalDamageDealtToChampions: 
-        :param totalDamageShieldedOnTeammates: 
-        :param totalDamageTaken: 
-        :param totalHeal: 
-        :param totalHealsOnTeammates: 
-        :param totalMinionsKilled: 
-        :param totalTimeCCDealt: 
-        :param totalTimeSpentDead: 
-        :param totalUnitsHealed: 
-        :param tripleKills: 
-        :param trueDamageDealt: 
-        :param trueDamageDealtToChampions: 
-        :param trueDamageTaken: 
-        :param turretKills: 
-        :param turretsLost: 
-        :param unrealKills: 
-        :param visionScore: 
-        :param visionWardsBoughtInGame: 
-        :param wardsKilled: 
-        :param wardsPlaced: 
-        :param win: 
-        :param inhibitorTakedowns: 
-        :param nexusTakedowns: 
-        :param turretTakedowns: 
-        :type assists: 
-        :type baronKills: 
-        :type bountyLevel: 
-        :type champExperience: 
-        :type champLevel: 
-        :type championId: 
-        :type championName: 
-        :type championTransform: 
-        :type consumablesPurchased: 
-        :type damageDealtToBuildings: 
-        :type damageDealtToObjectives: 
-        :type damageDealtToTurrets: 
-        :type damageSelfMitigated: 
-        :type deaths: 
-        :type detectorWardsPlaced: 
-        :type doubleKills: 
-        :type dragonKills: 
-        :type firstBloodAssist: 
-        :type firstBloodKill: 
-        :type firstTowerAssist: 
-        :type firstTowerKill: 
-        :type gameEndedInEarlySurrender: 
-        :type gameEndedInSurrender: 
-        :type goldEarned: 
-        :type goldSpent: 
-        :type individualPosition: 
-        :type inhibitorKills: 
-        :type inhibitorsLost: 
-        :type item0: 
-        :type item1: 
-        :type item2: 
-        :type item3: 
-        :type item4: 
-        :type item5: 
-        :type item6: 
-        :type itemsPurchased: 
-        :type killingSprees: 
-        :type kills: 
-        :type lane: 
-        :type largestCriticalStrike: 
-        :type largestKillingSpree: 
-        :type largestMultiKill: 
-        :type longestTimeSpentLiving: 
-        :type magicDamageDealt: 
-        :type magicDamageDealtToChampions: 
-        :type magicDamageTaken: 
-        :type neutralMinionsKilled: 
-        :type nexusKills: 
-        :type nexusLost: 
-        :type objectivesStolen: 
-        :type objectivesStolenAssists: 
-        :type participantId: 
-        :type pentaKills: 
-        :type perks: 
-        :type physicalDamageDealt: 
-        :type physicalDamageDealtToChampions: 
-        :type physicalDamageTaken: 
-        :type profileIcon: 
-        :type puuid: 
-        :type quadraKills: 
-        :type riotIdName: 
-        :type riotIdTagline: 
-        :type role: 
-        :type sightWardsBoughtInGame: 
-        :type spell1Casts: 
-        :type spell2Casts: 
-        :type spell3Casts: 
-        :type spell4Casts: 
-        :type summoner1Casts: 
-        :type summoner1Id: 
-        :type summoner2Casts: 
-        :type summoner2Id: 
-        :type summonerId: 
-        :type summonerLevel: 
-        :type summonerName: 
-        :type teamEarlySurrendered: 
-        :type teamId: 
-        :type teamPosition: 
-        :type timeCCingOthers: 
-        :type timePlayed: 
-        :type totalDamageDealt: 
-        :type totalDamageDealtToChampions: 
-        :type totalDamageShieldedOnTeammates: 
-        :type totalDamageTaken: 
-        :type totalHeal: 
-        :type totalHealsOnTeammates: 
-        :type totalMinionsKilled: 
-        :type totalTimeCCDealt: 
-        :type totalTimeSpentDead: 
-        :type totalUnitsHealed: 
-        :type tripleKills: 
-        :type trueDamageDealt: 
-        :type trueDamageDealtToChampions: 
-        :type trueDamageTaken: 
-        :type turretKills: 
-        :type turretsLost: 
-        :type unrealKills: 
-        :type visionScore: 
-        :type visionWardsBoughtInGame: 
-        :type wardsKilled: 
-        :type wardsPlaced: 
-        :type win: 
-        :type inhibitorTakedowns: 
-        :type nexusTakedowns: 
-        :type turretTakedowns: 
+
+        :param assists:
+        :param baronKills:
+        :param bountyLevel:
+        :param champExperience:
+        :param champLevel:
+        :param championId:
+        :param championName:
+        :param championTransform:
+        :param consumablesPurchased:
+        :param damageDealtToBuildings:
+        :param damageDealtToObjectives:
+        :param damageDealtToTurrets:
+        :param damageSelfMitigated:
+        :param deaths:
+        :param detectorWardsPlaced:
+        :param doubleKills:
+        :param dragonKills:
+        :param firstBloodAssist:
+        :param firstBloodKill:
+        :param firstTowerAssist:
+        :param firstTowerKill:
+        :param gameEndedInEarlySurrender:
+        :param gameEndedInSurrender:
+        :param goldEarned:
+        :param goldSpent:
+        :param individualPosition:
+        :param inhibitorKills:
+        :param inhibitorsLost:
+        :param item0:
+        :param item1:
+        :param item2:
+        :param item3:
+        :param item4:
+        :param item5:
+        :param item6:
+        :param itemsPurchased:
+        :param killingSprees:
+        :param kills:
+        :param lane:
+        :param largestCriticalStrike:
+        :param largestKillingSpree:
+        :param largestMultiKill:
+        :param longestTimeSpentLiving:
+        :param magicDamageDealt:
+        :param magicDamageDealtToChampions:
+        :param magicDamageTaken:
+        :param neutralMinionsKilled:
+        :param nexusKills:
+        :param nexusLost:
+        :param objectivesStolen:
+        :param objectivesStolenAssists:
+        :param participantId:
+        :param pentaKills:
+        :param perks:
+        :param physicalDamageDealt:
+        :param physicalDamageDealtToChampions:
+        :param physicalDamageTaken:
+        :param profileIcon:
+        :param puuid:
+        :param quadraKills:
+        :param riotIdName:
+        :param riotIdTagline:
+        :param role:
+        :param sightWardsBoughtInGame:
+        :param spell1Casts:
+        :param spell2Casts:
+        :param spell3Casts:
+        :param spell4Casts:
+        :param summoner1Casts:
+        :param summoner1Id:
+        :param summoner2Casts:
+        :param summoner2Id:
+        :param summonerId:
+        :param summonerLevel:
+        :param summonerName:
+        :param teamEarlySurrendered:
+        :param teamId:
+        :param teamPosition:
+        :param timeCCingOthers:
+        :param timePlayed:
+        :param totalDamageDealt:
+        :param totalDamageDealtToChampions:
+        :param totalDamageShieldedOnTeammates:
+        :param totalDamageTaken:
+        :param totalHeal:
+        :param totalHealsOnTeammates:
+        :param totalMinionsKilled:
+        :param totalTimeCCDealt:
+        :param totalTimeSpentDead:
+        :param totalUnitsHealed:
+        :param tripleKills:
+        :param trueDamageDealt:
+        :param trueDamageDealtToChampions:
+        :param trueDamageTaken:
+        :param turretKills:
+        :param turretsLost:
+        :param unrealKills:
+        :param visionScore:
+        :param visionWardsBoughtInGame:
+        :param wardsKilled:
+        :param wardsPlaced:
+        :param win:
+        :param inhibitorTakedowns:
+        :param nexusTakedowns:
+        :param turretTakedowns:
+        :type assists:
+        :type baronKills:
+        :type bountyLevel:
+        :type champExperience:
+        :type champLevel:
+        :type championId:
+        :type championName:
+        :type championTransform:
+        :type consumablesPurchased:
+        :type damageDealtToBuildings:
+        :type damageDealtToObjectives:
+        :type damageDealtToTurrets:
+        :type damageSelfMitigated:
+        :type deaths:
+        :type detectorWardsPlaced:
+        :type doubleKills:
+        :type dragonKills:
+        :type firstBloodAssist:
+        :type firstBloodKill:
+        :type firstTowerAssist:
+        :type firstTowerKill:
+        :type gameEndedInEarlySurrender:
+        :type gameEndedInSurrender:
+        :type goldEarned:
+        :type goldSpent:
+        :type individualPosition:
+        :type inhibitorKills:
+        :type inhibitorsLost:
+        :type item0:
+        :type item1:
+        :type item2:
+        :type item3:
+        :type item4:
+        :type item5:
+        :type item6:
+        :type itemsPurchased:
+        :type killingSprees:
+        :type kills:
+        :type lane:
+        :type largestCriticalStrike:
+        :type largestKillingSpree:
+        :type largestMultiKill:
+        :type longestTimeSpentLiving:
+        :type magicDamageDealt:
+        :type magicDamageDealtToChampions:
+        :type magicDamageTaken:
+        :type neutralMinionsKilled:
+        :type nexusKills:
+        :type nexusLost:
+        :type objectivesStolen:
+        :type objectivesStolenAssists:
+        :type participantId:
+        :type pentaKills:
+        :type perks:
+        :type physicalDamageDealt:
+        :type physicalDamageDealtToChampions:
+        :type physicalDamageTaken:
+        :type profileIcon:
+        :type puuid:
+        :type quadraKills:
+        :type riotIdName:
+        :type riotIdTagline:
+        :type role:
+        :type sightWardsBoughtInGame:
+        :type spell1Casts:
+        :type spell2Casts:
+        :type spell3Casts:
+        :type spell4Casts:
+        :type summoner1Casts:
+        :type summoner1Id:
+        :type summoner2Casts:
+        :type summoner2Id:
+        :type summonerId:
+        :type summonerLevel:
+        :type summonerName:
+        :type teamEarlySurrendered:
+        :type teamId:
+        :type teamPosition:
+        :type timeCCingOthers:
+        :type timePlayed:
+        :type totalDamageDealt:
+        :type totalDamageDealtToChampions:
+        :type totalDamageShieldedOnTeammates:
+        :type totalDamageTaken:
+        :type totalHeal:
+        :type totalHealsOnTeammates:
+        :type totalMinionsKilled:
+        :type totalTimeCCDealt:
+        :type totalTimeSpentDead:
+        :type totalUnitsHealed:
+        :type tripleKills:
+        :type trueDamageDealt:
+        :type trueDamageDealtToChampions:
+        :type trueDamageTaken:
+        :type turretKills:
+        :type turretsLost:
+        :type unrealKills:
+        :type visionScore:
+        :type visionWardsBoughtInGame:
+        :type wardsKilled:
+        :type wardsPlaced:
+        :type win:
+        :type inhibitorTakedowns:
+        :type nexusTakedowns:
+        :type turretTakedowns:
         """
         super().__init__(**kwargs)
         self.assists = assists
